@@ -1,14 +1,11 @@
-from datetime import datetime
 import csv
-import feedparser
+from datetime import datetime
+import os
 from .post import Post
 
 
 class Home():
     def __init__(self):
-        self.feed = feedparser.parse('http://www.facebook.com/feeds/page.php?format=atom10&id=121855461256134')
-        print(self.feed['feed']['title'])
-
         print(
             '\nWelcome to SIGACTor, currently available '
             'for the Syria team and reading posts from the '
@@ -38,7 +35,12 @@ class Home():
 
         print('\nPreparing CSV...')
         self.today = datetime.now()
-        self.document_title = self.today.strftime('%Y-%m-%dT%H-%M') + '.csv'
+        self.csv_title = self.today.strftime('%Y-%m-%dT%H-%M') + '.csv'
+        self.csv_directory = os.path.join(os.path.expanduser('~'), 'SIGACTS')
+        self.csv_path = os.path.join(self.csv_directory, self.csv_title)
+
+        if not os.path.exists(self.csv_directory):
+            os.makedirs(self.csv_directory)
 
         self.csvwrite(self.properties)
 
@@ -77,10 +79,10 @@ class Home():
                 )
 
         print(
-            '\nSaved CSV as', self.document_title,
+            '\nSaved CSV as', self.csv_path,
         )
 
     def csvwrite(self, values):
-        with open(self.document_title, 'a', newline='') as csvfile:
+        with open(self.csv_path, 'a', newline='') as csvfile:
             csvwriter = csv.writer(csvfile, dialect='excel')
             csvwriter.writerow(values)
